@@ -40,7 +40,7 @@ try:
 except ImportError:
     pass
 
-__version__ = "1.13.5"
+__version__ = "2.0.0"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_Wiznet5k.git"
 
 from random import randint
@@ -84,8 +84,8 @@ SNSR_SOCK_SYNRECV = const(0x16)
 SNSR_SOCK_ESTABLISHED = const(0x17)
 SNSR_SOCK_FIN_WAIT = const(0x18)
 _SNSR_SOCK_CLOSING = const(0x1A)
-_SNSR_SOCK_TIME_WAIT = const(0x1B)
-_SNSR_SOCK_CLOSE_WAIT = const(0x1C)
+SNSR_SOCK_TIME_WAIT = const(0x1B)
+SNSR_SOCK_CLOSE_WAIT = const(0x1C)
 _SNSR_SOCK_LAST_ACK = const(0x1D)
 _SNSR_SOCK_UDP = const(0x22)
 _SNSR_SOCK_IPRAW = const(0x32)
@@ -266,11 +266,13 @@ class WIZNET5K:  # pylint: disable=too-many-public-methods, too-many-instance-at
         :return Union[int, bytes]: a 4 bytearray.
         """
         if self._debug:
-            print("* Get host by name")
+            print(f"* Get host by name : {hostname}")
         if isinstance(hostname, str):
             hostname = bytes(hostname, "utf-8")
         # Return IP assigned by DHCP
-        _dns_client = dns.DNS(self, self._dns, debug=self._debug)
+        _dns_client = dns.DNS(
+            self, self.pretty_ip(bytearray(self._dns)), debug=self._debug
+        )
         ret = _dns_client.gethostbyname(hostname)
         if self._debug:
             print("* Resolved IP: ", ret)
@@ -824,9 +826,9 @@ class WIZNET5K:  # pylint: disable=too-many-public-methods, too-many-instance-at
         status = self._read_snsr(socket_num)[0]
         if status in (
             SNSR_SOCK_CLOSED,
-            _SNSR_SOCK_TIME_WAIT,
+            SNSR_SOCK_TIME_WAIT,
             SNSR_SOCK_FIN_WAIT,
-            _SNSR_SOCK_CLOSE_WAIT,
+            SNSR_SOCK_CLOSE_WAIT,
             _SNSR_SOCK_CLOSING,
             _SNSR_SOCK_UDP,
         ):
@@ -904,7 +906,7 @@ class WIZNET5K:  # pylint: disable=too-many-public-methods, too-many-instance-at
         if ret == 0:
             # no data on socket?
             status = self._read_snmr(socket_num)
-            if status in (SNSR_SOCK_LISTEN, SNSR_SOCK_CLOSED, _SNSR_SOCK_CLOSE_WAIT):
+            if status in (SNSR_SOCK_LISTEN, SNSR_SOCK_CLOSED, SNSR_SOCK_CLOSE_WAIT):
                 # remote end closed its side of the connection, EOF state
                 ret = 0
                 resp = 0
@@ -991,9 +993,6 @@ class WIZNET5K:  # pylint: disable=too-many-public-methods, too-many-instance-at
         if not self.link_status:
             raise ConnectionError("Ethernet cable disconnected!")
         assert socket_num <= self.max_sockets, "Provided socket exceeds max_sockets."
-        status = 0
-        ret = 0
-        free_size = 0
         if len(buffer) > _SOCK_SIZE:
             ret = _SOCK_SIZE
         else:
@@ -1005,7 +1004,7 @@ class WIZNET5K:  # pylint: disable=too-many-public-methods, too-many-instance-at
         while free_size < ret:
             free_size = self._get_tx_free_size(socket_num)
             status = self.socket_status(socket_num)[0]
-            if status not in (SNSR_SOCK_ESTABLISHED, _SNSR_SOCK_CLOSE_WAIT) or (
+            if status not in (SNSR_SOCK_ESTABLISHED, SNSR_SOCK_CLOSE_WAIT) or (
                 timeout and time.monotonic() - stamp > timeout
             ):
                 ret = 0
@@ -1050,9 +1049,9 @@ class WIZNET5K:  # pylint: disable=too-many-public-methods, too-many-instance-at
         ) != _SNIR_SEND_OK:
             if self.socket_status(socket_num)[0] in (
                 SNSR_SOCK_CLOSED,
-                _SNSR_SOCK_TIME_WAIT,
+                SNSR_SOCK_TIME_WAIT,
                 SNSR_SOCK_FIN_WAIT,
-                _SNSR_SOCK_CLOSE_WAIT,
+                SNSR_SOCK_CLOSE_WAIT,
                 _SNSR_SOCK_CLOSING,
             ) or (timeout and time.monotonic() - stamp > timeout):
                 # self.socket_close(socket_num)
